@@ -727,4 +727,15 @@ $('#' + boxid).closest('.box').find('[data-widget=collapse]').click();
 "
 
 # Global variables to avoid NOTE
-globalVariables("js")
\ No newline at end of file
+globalVariables("js")
+
+# Check internet connection
+havingIP <- function() {
+  if (.Platform$OS.type == "windows") {
+    ipmessage <- system("ipconfig", intern = TRUE)
+  } else {
+    ipmessage <- system("ifconfig", intern = TRUE)
+  }
+  validIP <- "((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)[.]){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)"
+  any(grep(validIP, ipmessage))
+}
